"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const system_1 = require("../system");
const errors_1 = require("./errors");
/**
 * An HTTP request object.
 *
 * @export
 * @class Request
 */
class Request {
    /**
     * Creates an instance of Request.
     * @param {APIGatewayEvent} event
     * @memberof Request
     */
    constructor(event) {
        this.auth = null;
        this.headers = {};
        this.event = event;
        this.body = event.body;
        this.path = event.path;
        this.method = event.httpMethod;
        this.params = event.pathParameters;
        this.query = event.queryStringParameters;
        this.id = event.requestContext.requestId;
        // Normalize all header keys with capitalization.
        for (let key in event.headers) {
            let value = event.headers[key];
            key = key.replace(/(^[a-zA-Z]|-[a-zA-Z])/g, (str, char) => {
                return str.replace(char, char.toUpperCase());
            });
            this.headers[key] = value;
        }
        this.parseBody();
    }
    /**
     * Parses the body of a request if the Content-Type header is
     * application/json. If parsing fails, a Bad Request is thrown.
     *
     * @private
     * @throws {BadRequest}
     * @memberof Request
     */
    parseBody() {
        let content = this.headers['Content-Type'];
        if (content && content.includes('application/json')) {
            try {
                this.data = JSON.parse(this.body);
            }
            catch (err) {
                system_1.log.error(err);
                throw new errors_1.BadRequest('Parsing the request body failed.');
            }
        }
    }
}
exports.Request = Request;
//# sourceMappingURL=request.js.map