/**
 * An http response object.
 *
 * @export
 * @class Response
 */
export declare class Response {
    /**
     * The response headers.
     *
     * @type {{ [name: string]: string }}
     * @memberof Response
     */
    headers: {
        [name: string]: string;
    };
    /**
     * The status code of the response.
     *
     * @type {number}
     * @memberof Response
     */
    code: number;
    /**
     * The body of the response.
     *
     * @type {object}
     * @memberof Response
     */
    body: object;
    /**
     * Creates an instance of Response.
     * @param {number} [code=200]
     * @param {object} [body={}]
     * @memberof Response
     */
    constructor(code?: number, body?: object);
    /**
     * Returns an object suitable for a serverless response.
     *
     * @returns any
     * @memberof Response
     */
    toLambdaResponse(): {
        headers: {
            [name: string]: string;
        };
        statusCode: number;
        body: string;
    };
}
