"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const middleware_1 = require("./middleware");
const system_1 = require("../system");
/**
 * Logs requests and responses as JSON.
 *
 * @export
 * @class JSONLogger
 * @extends {Middleware}
 */
class JSONLogger extends middleware_1.Middleware {
    /**
     * Creates an instance of JSONLogger.
     * @param {string} name
     * @param {string} [level='info']
     * @memberof JSONLogger
     */
    constructor(name, level = 'info') {
        super();
        /**
         * Logs selected request values as JSON.
         *
         * @param {Request} req
         * @param {Response} res
         * @memberof JSONLogger
         */
        this.processRequest = (req, res) => __awaiter(this, void 0, void 0, function* () {
            let msg = {
                id: req.id,
                path: req.path,
                query: req.query,
                params: req.params,
                method: req.method,
                body: req.body,
            };
            this.log.info(msg);
        });
        /**
         * Logs selected response values as JSON.
         *
         * @param {Request} req
         * @param {Response} res
         * @returns {Promise<any>}
         * @memberof JSONLogger
         */
        this.processResponse = (req, res) => __awaiter(this, void 0, void 0, function* () {
            let msg = {
                id: req.id,
                code: res.code,
                body: res.body
            };
            this.log.info(msg);
        });
        this.log = system_1.getLogger(name, level);
    }
    /**
     * Add a NodeJS.WriteStream stream to the list of log targets.
     *
     * @param {NodeJS.WriteStream} stream
     * @memberof JSONLogger
     */
    addStream(stream) {
        let writeStream = {
            level: this.level,
            stream: stream
        };
        this.log.addStream(writeStream);
    }
}
exports.JSONLogger = JSONLogger;
//# sourceMappingURL=logging.js.map